# TEMPLATE DIRECTORY for new parser plugins.

How to use this:

* copy this entire directory to a new folder called `lute-<yourlangname>`
* find langname or LangName in all files and filenames, change to your language's name.  e.g., for Thai, `langname` = `thai`, and `LangName` = `Thai`
* implement your class and tests
* fix any remaining TODO items in the files
* delete this section from the README and only include the relevant content below :-)


# README

The Lute LangName parser.

TODO fix file

See [the wiki](https://github.com/LuteOrg/lute-v3/wiki/Developing-language-parser-plugins) for development notes.

See the [Pypi readme](./README_PyPi.md) for extra config notes.